--------------
ObsPack README
--------------

ObsPack Fair Use Statement
--------------------------

This data product is made available to the scientific community and is intended to support UK activities into emission estimation.  We rely on the ethics and integrity of the user to assure that each contributing national and university laboratory receives fair credit for their work. Fair credit will depend on the nature of the work and the requirements of the institutions involved.
Your use of this data product implies an agreement to contact each contributing laboratory for data sets used to discuss the nature of the work and the appropriate level of acknowledgement. If this product is essential to the work, or if an important result or conclusion depends on this product, co-authorship may be appropriate. This should be discussed with the appropriate data providers at an early stage in the work.  Contacting the data providers is not optional; if you use this data product, you must contact the applicable data providers.  To help you meet your obligation, the data product includes a list of sites along with the associated names and e-mail addresses for the data providers.

Product Warning
---------------

Every effort is made to create the most accurate and precise data product possible. Contributors reserve the right to make corrections to this product and data based on recalibration of standard gases or for other reasons deemed scientifically justified. Contributors to this product are not responsible for results and conclusions based on use of this product without regard to this warning.
